# encoding: utf-8
require 'spec_helper'
require "logstash/filters/sumo"

describe LogStash::Filters::Sumo do
  describe "Dashvod" do
    let(:config) do <<-CONFIG
      filter {
        sumo {
        }
      }
    CONFIG
    end

    sample("page"=>"/dashvod/_definst_/amlst:993514_ps20000_pd1291830.smil/chunk_ctaudio_cfm4s_ridp0a1r1_cs28929600_mpd.m4s" ) do
      insist { subject.get('path_type') } == 'dashvod'

      expect(subject.get('dist_type')).to eq('vod')
      expect(subject.get('video_type')).to eq('m4s')
      expect(subject.get('asset_id')).to eq(993514)
    end

  end

  describe "ismusp" do
    let(:config) do <<-CONFIG
      filter {
        sumo {
        }
      }
    CONFIG
    end

    sample("page"=>"/ismusp/2013-10-22/N_RYANAIR_221013_TOB_NET(763009_R22MP41000).mp4" ) do
      insist { subject.get('path_type') } == 'ismusp'

      expect(subject.get('dist_type')).to eq('vod')
      expect(subject.get('video_type')).to eq('mp4')
      expect(subject.get('asset_id')).to eq(763009)
    end

    #
    sample("page"=>"/origin2-od.akamai.tv2.no/ismusp/isi_mp4_0/2014-04-25/G018902sumo(809735_ISMUSP).ism/Manifest" ) do
      insist { subject.get('path_type') } == 'ismusp'

      expect(subject.get('dist_type')).to eq('vod')
      expect(subject.get('video_type')).to eq('ism')
      expect(subject.get('vtype')).to eq('manifest')
      expect(subject.get('asset_id')).to eq(809735)
      expect(subject.get('cache_key')).to eq("origin2-od.akamai.tv2.no")

    end
  end

  describe "vod2" do
    let(:config) do <<-CONFIG
      filter {
        sumo {
        }
      }
    CONFIG
    end

    sample("page"=>"/vod2/_definst_/amlst:1027448_ps55210_pd1373700_HRDNGR.smil/media_b6378000_43.ts" ) do
      insist { subject.get('path_type') } == 'vod2'
      expect(subject.get('dist_type')).to eq('vod')
      expect(subject.get('video_type')).to eq('ts')
      expect(subject.get('asset_id')).to eq(1027448)
    end

  end

  describe "wzlive" do
    let(:config) do <<-CONFIG
      filter {
        sumo {
        }
      }
    CONFIG
    end

    sample("page"=>"/wzlive/_definst_/amlst:LS6/433127.smil/manifest.mpd" ) do
      insist { subject.get('path_type') } == 'wzlive'
      expect(subject.get('dist_type')).to eq('live')
      expect(subject.get('video_type')).to eq('mpd')
      expect(subject.get('asset_id')).to eq(433127)
    end

  end


  describe "wzlive" do
    let(:config) do <<-CONFIG
      filter {
        sumo {
        }
      }
    CONFIG
    end

    sample("page"=>"/ismvod/_definst_/amlst:1027479.smil.ism/QualityLevels(126793)/Fragments(audio=143034920).isma" ) do
      insist { subject.get('path_type') } == 'ismvod'
      expect(subject.get('dist_type')).to eq('vod')
      expect(subject.get('video_type')).to eq('isma')
      expect(subject.get('asset_id')).to eq(1027479)
    end

  end

  describe "Different field" do
    let(:config) do <<-CONFIG
      filter {
        sumo {
          field => "pg"
        }
      }
    CONFIG
    end

    sample("pg"=>"/ismvod/_definst_/amlst:1027479.smil.ism/QualityLevels(126793)/Fragments(audio=143034920).isma" ) do
      insist { subject.get('path_type') } == 'ismvod'
      expect(subject.get('dist_type')).to eq('vod')
      expect(subject.get('video_type')).to eq('isma')
      expect(subject.get('asset_id')).to eq(1027479)
    end

  end

  describe "Live url /live/727992.isml" do
    let(:config) do <<-CONFIG
      filter {
        sumo {
          field => "pg"
        }
      }
    CONFIG
    end

    sample("pg"=>"/live/727992.isml" ) do
      insist { subject.get('path_type') } == 'isml'
      expect(subject.get('dist_type')).to eq('vod')
      expect(subject.get('video_type')).to eq('isml')
      expect(subject.get('asset_id')).to eq(727992)
    end

  end


  describe "Live url /out/u/463577.mpd" do
    let(:config) do <<-CONFIG
      filter {
        sumo {
          field => "pg"
        }
      }
    CONFIG
    end

    sample("pg"=>"/out/u/463577.mpd" ) do
      insist { subject.get('path_type') } == 'elemental live'
      expect(subject.get('dist_type')).to eq('live')
      expect(subject.get('video_type')).to eq('dash')
      expect(subject.get('asset_id')).to eq(463577)
    end

  end

  describe "Live url /out/u/463577_video_1_0_3425579.mp4?m=1500616216" do
    let(:config) do <<-CONFIG
      filter {
        sumo {
          field => "pg"
        }
      }
    CONFIG
    end

    sample("pg"=>"/out/u/463577_video_1_0_3425579.mp4?m=1500616216" ) do
      insist { subject.get('path_type') } == 'elemental live'
      expect(subject.get('dist_type')).to eq('live')
      expect(subject.get('video_type')).to eq('dash')
      expect(subject.get('asset_id')).to eq(463577)
    end

  end

  describe "Live url /out/u/880009.m3u8" do
    let(:config) do <<-CONFIG
      filter {
        sumo {
          field => "pg"
        }
      }
    CONFIG
    end

    sample("pg"=>"/out/u/463577_video_1_0_3425579.mp4?m=1500616216" ) do
      insist { subject.get('path_type') } == 'elemental live'
      expect(subject.get('dist_type')).to eq('live')
      expect(subject.get('video_type')).to eq('dash')
      expect(subject.get('asset_id')).to eq(463577)
      expect(subject.get('vtype')).to eq("segment")
    end

  end

  describe "Live url /out/u/880009_6.m3u8" do
    let(:config) do <<-CONFIG
      filter {
        sumo {
          field => "pg"
        }
      }
    CONFIG
    end

    sample("pg"=>"/out/u/880009_6.m3u8" ) do
      insist { subject.get('path_type') } == 'elemental live'
      expect(subject.get('dist_type')).to eq('live')
      expect(subject.get('video_type')).to eq('hls')
      expect(subject.get('asset_id')).to eq(880009)
      expect(subject.get('vtype')).to eq("chunklist")
    end

  end





  describe "Live url /out/u/880009_6_3584645.ts?m=1501848254" do
    let(:config) do <<-CONFIG
      filter {
        sumo {
          field => "pg"
        }
      }
    CONFIG
    end

    sample("pg"=>"/out/u/880009_6_3584645.ts?m=1501848254" ) do
      insist { subject.get('path_type') } == 'elemental live'
      expect(subject.get('dist_type')).to eq('live')
      expect(subject.get('video_type')).to eq('hls')
      expect(subject.get('asset_id')).to eq(880009)
      expect(subject.get('vtype')).to eq("segment")
    end

  end




  describe "Live url /out/u/880009.ism/Manifest" do
    let(:config) do <<-CONFIG
      filter {
        sumo {
          field => "pg"
        }
      }
    CONFIG
    end

    sample("pg"=>"/out/u/880009.ism/Manifest" ) do
      insist { subject.get('path_type') } == 'elemental live'
      expect(subject.get('dist_type')).to eq('live')
      expect(subject.get('video_type')).to eq('ism')
      expect(subject.get('asset_id')).to eq(880009)
      expect(subject.get('vtype')).to eq("manifest")
    end

  end


  describe "Live url /out/u/880009.ism/Events(72_1501848239)/QualityLevels(2499968)/Fragments(v=77110176346666)" do
    let(:config) do <<-CONFIG
      filter {
        sumo {
          field => "pg"
        }
      }
    CONFIG
    end

    sample("pg"=>"/out/u/880009.ism/Events(72_1501848239)/QualityLevels(2499968)/Fragments(v=77110176346666)" ) do
      insist { subject.get('path_type') } == 'elemental live'
      expect(subject.get('dist_type')).to eq('live')
      expect(subject.get('video_type')).to eq('ism')
      expect(subject.get('asset_id')).to eq(880009)
      expect(subject.get('vtype')).to eq("segment")
    end

  end


  describe "VOD url 2017-09-13 11:00:02 W3SVC1 wmosl8 195.5.113.121 GET /ismvod7/_definst_/amlst:1156413.smil.ism/QualityLevels(125666)/Fragments(audio=2201948299).isma X-ARR-CACHE-HIT=0&SERVER-ROUTED=193.160.157.68&X-ARR-LOG-ID=be27667e-7b28-42c8-ac4a-60b2082e7e45&SERVER-STATUS=200 80 - 148.123.2.6 HTTP/1.1 SSPK+client/1.51+(compatible;+LG+NetCast.TV-2013) - multicdn2.local 200 0 0 34219 497 18
" do
    let(:config) do <<-CONFIG
      filter {
        sumo {
          field => "pg"
        }
      }
    CONFIG
    end

    sample("pg"=>"/ismvod7/_definst_/amlst:1156413.smil.ism/QualityLevels(125666)/Fragments(audio=2201948299).isma" ) do
      insist { subject.get('path_type') } == 'ismvod'
      expect(subject.get('dist_type')).to eq('vod')
      expect(subject.get('video_type')).to eq('isma')
      expect(subject.get('asset_id')).to eq(1156413)
      expect(subject.get('vtype')).to eq("segment")
    end

  end


  describe "VOD url /hdsvod/_definst_/amlst:1230502_ps1140_pd2071840.smil/media_b2003000.abst/Seg1-Frag891" do
    let(:config) do <<-CONFIG
      filter {
        sumo {
          field => "pg"
        }
      }
    CONFIG
    end

    sample("pg"=>"/hdsvod/_definst_/amlst:1230502_ps1140_pd2071840.smil/media_b2003000.abst/Seg1-Frag891" ) do
      insist { subject.get('path_type') } == 'wowza vod'
      expect(subject.get('dist_type')).to eq('vod')
      expect(subject.get('video_type')).to eq('hds')
      expect(subject.get('asset_id')).to eq(1230502)
      expect(subject.get('vtype')).to eq("segment")
    end

  end



  describe "VOD url  /vod4/_definst_/amlst:1224663_ps60000_pd1482000_HRDNGR.smil/media_b1250000_ko_152.ts" do
    let(:config) do <<-CONFIG
      filter {
        sumo {
          field => "pg"
        }
      }
    CONFIG
    end

    sample("pg"=>"/vod4/_definst_/amlst:1224663_ps60000_pd1482000_HRDNGR.smil/media_b1250000_ko_152.ts" ) do
      insist { subject.get('path_type') } == 'vod'
      expect(subject.get('dist_type')).to eq('vod')
      expect(subject.get('video_type')).to eq('ts')
      expect(subject.get('asset_id')).to eq(1224663)
      expect(subject.get('vtype')).to eq("segment")
    end


  end

  describe "ISML url  /origin1-live.akamai.tv2.no/live/727992.isml/Manifest" do
    let(:config) do <<-CONFIG
      filter {
        sumo {
          field => "pg"
        }
      }
    CONFIG
    end


    # /origin1-live.akamai.tv2.no/live/727992.isml/Manifest
    sample("pg"=>"/origin1-live.akamai.tv2.no/live/727992.isml/Manifest" ) do
      insist { subject.get('path_type') } == 'live'
      expect(subject.get('dist_type')).to eq('live')
      expect(subject.get('video_type')).to eq('ism')
      expect(subject.get('asset_id')).to eq(727992)
      expect(subject.get('vtype')).to eq("manifest")
      expect(subject.get('cache_key')).to eq("origin1-live.akamai.tv2.no")
    end

    # /origin1-live.akamai.tv2.no/live/727992.isml/Manifest
    sample("pg"=>"/origin3-hlslive.akamai.tv2.no/out/u/1285463.ism/Manifest" ) do
      insist { subject.get('path_type') } == 'elemental live'
      expect(subject.get('dist_type')).to eq('live')
      expect(subject.get('video_type')).to eq('ism')
      expect(subject.get('asset_id')).to eq(1285463)
      expect(subject.get('vtype')).to eq("manifest")
      expect(subject.get('cache_key')).to eq("origin3-hlslive.akamai.tv2.no")
    end
  end

  # /stagevod/_definst_/amlst:1212305_ps97070_pd3161140.smil.ism/Manifest
  describe "ISML url  /stagevod/_definst_/amlst:1212305_ps97070_pd3161140.smil.ism/Manifes" do
    let(:config) do <<-CONFIG
      filter {
        sumo {
          field => "pg"
        }
      }
    CONFIG
    end

    sample("pg"=>" /stagevod/_definst_/amlst:1212305_ps97070_pd3161140.smil.ism/Manifest" ) do
      insist { subject.get('path_type') } == 'ismvod'
      expect(subject.get('dist_type')).to eq('vod')
      expect(subject.get('video_type')).to eq('ism')
      expect(subject.get('asset_id')).to eq(1212305)
      expect(subject.get('vtype')).to eq("manifest")
    end

  end

  end
